State class

Handle state data such as: (name, countryCode, isoCode, latitude, longitude)

Constructors

State({required String name, required String countryCode, required String isoCode, String? latitude, String? longitude})

Properties

countryCode → String
final
hashCode → int
The hash code for this object.
no setterinherited
isoCode → String
final
latitude → String?
final
longitude → String?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → State