Timezone class

Handle timezone data such as: (name, gmtOffset, gmtOffsetName, abbreviation, tzName)

Constructors

Timezone({required String name, required String gmtOffset, required String gmtOffsetName, required String abbreviation, required String tzName})

Properties

abbreviation → String
final
gmtOffset → String
final
gmtOffsetName → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tzName → String
final

Methods

fromJson(Map<String, dynamic> json) → Timezone
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited